@@ -1,3 +1,4 @@
+use ergo_lib::ergo_rest::NodeError;
 use std::error;
 use thiserror::Error;
 
@@ -28,3 +29,9 @@ impl Error {
         }
     }
 }
+
+impl From<NodeError> for Error {
+    fn from(error: NodeError) -> Self {
+        Error::Misc(format!("{:?}", error).into())
+    }
+}
